#
# spec file for package liboqs
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           liboqs
Version:        0.8.0
Release:        1.2
Summary:        C library for quantum-resistant cryptographic algorithms
License:        MIT
Group:          Productivity/Security
URL:            https://github.com/open-quantum-safe/liboqs/
Source:         https://github.com/open-quantum-safe/liboqs/archive/refs/tags/%{version}.tar.gz
Source1:        baselibs.conf
Patch0:         liboqs-fix-build.patch
Patch1:         liboqs-fix-prototypemismatch.patch
BuildRequires:  cmake
BuildRequires:  doxygen
BuildRequires:  libopenssl-devel

%description
liboqs is a C library for quantum-resistant cryptographic algorithms.
See the bundled README.md for particular limitations on intended use.

%package -n liboqs3
Summary:        C library for quantum-resistant cryptographic algorithms
Group:          System/Libraries

%description -n liboqs3
liboqs is a C library for quantum-resistant cryptographic algorithms.
See the bundled README.md for particular limitations on intended use.

%package devel
Summary:        Headers for liboqs, a library for quantum-resistant cryptography
Group:          Development/Languages/C and C++
Requires:       liboqs3 = %{version}

%description devel
liboqs is a C library for quantum-resistant cryptographic algorithms.
See the bundled README.md for particular limitations on intended use.

%prep
%autosetup -p1

%build
export RPM_OPT_FLAGS="%{optflags} -std=gnu11"

# 20220702: The %%cmake macro can't be used because a 'CMakeLists.txt' folder
# exists
cmake -S . -B build -DBUILD_SHARED_LIBS:BOOL=ON -DOQS_DIST_BUILD:BOOL=ON

pushd build
%cmake_build
popd

%install
%cmake_install

# need to find out what cmake option is needed
mv %{buildroot}%{_prefix}/local/* %{buildroot}%{_prefix}

#if [ "%{_lib}" != "lib" ]; then
  # mv %{buildroot}%{_prefix}/lib %{buildroot}%{_libdir}
#fi

rmdir %{buildroot}%{_prefix}/local/

%post -n liboqs3 -p /sbin/ldconfig
%postun -n liboqs3 -p /sbin/ldconfig

%files -n liboqs3
%license LICENSE.txt
%{_libdir}/liboqs.so.0.8.0
%{_libdir}/liboqs.so.3
%doc README.md

%files devel
%license LICENSE.txt
%dir %{_includedir}/oqs
%{_includedir}/oqs/*
%{_libdir}/liboqs.so
%{_libdir}/pkgconfig/liboqs.pc
%dir %{_libdir}/cmake/
%dir %{_libdir}/cmake/liboqs/
%{_libdir}/cmake/liboqs/liboqsTargets-noconfig.cmake
%{_libdir}/cmake/liboqs/liboqsTargets.cmake
%{_libdir}/cmake/liboqs/liboqsConfig.cmake
%{_libdir}/cmake/liboqs/liboqsConfigVersion.cmake

%changelog
* Thu Jun  8 2023 Marcus Meissner <meissner@suse.com>
- updated to 0.8.0
  This release features many algorithm updates, including removal
  of algorithms and variants no longer proceeding through NIST
  standardization and updates to newer versions.  See the detailed list
  of algorithm updates below.
  Key encapsulation mechanisms:
  - BIKE: updated to Round 4 version.
  - Kyber: 90s variants were removed.
  - NTRU Prime: All variants were removed, except for sntrup761.
  - Saber: removed.
  Digital signature schemes
  - Dilithium; AES variants were removed.
  - Falcon: updated to the 2023-02-07 version.
  - Picnic: removed.
  - Rainbow: removed.
  - SPHINCS+: updated to version 3.1; SPHINCS+-Haraka variants were removed; SPHINCS+-SHA256 and SPHINCS+-SHAKE variants were renamed
  Other changes
  - Add Cryptographic Bill of Materials (CBOM)
  - Improve building on ARM platforms
  - Improve performance when using OpenSSL 3 for symmetric cryptography
  - Increment shared object library version
  - New configure-time options for algorithm selections
  - pkgconfig file now available
- removed 0001-Add-support-for-powerpc64.-1160.patch: upstream
- 0002-Mark-stack-non-executable-when-compiling-with-clang-.patch: upstream
- liboqs is now liboqs.so.3.
* Wed Mar 29 2023 Marcus Meissner <meissner@suse.com>
- liboqs-fix-prototypemismatch.patch: fixed uint8_t* vs unsigned char* mismatch
- disable -Werror for now.
* Tue Nov 15 2022 Jan Engelhardt <jengelh@inai.de>
- Ship the README.md mentioned in the description.
- Compact descriptions.
* Sat Jul  2 2022 Christophe Giboudeaux <christophe@krop.fr>
- Add upstream changes:
  * 0001-Add-support-for-powerpc64.-1160.patch
  * 0002-Mark-stack-non-executable-when-compiling-with-clang-.patch
- Spec cleanup
* Tue Jan 25 2022 Bernhard Wiedemann <bwiedemann@suse.com>
- Stop building with march=native to get reproducible binaries (boo#1100677)
* Sun Jan  2 2022 Jan Engelhardt <jengelh@inai.de>
- Trim redundancies from description. Remove old specfile
  constructs.
* Fri Nov 12 2021 Marcus Meissner <meissner@suse.com>
- initial import of the liboqs Open Quantum Safe library, version 0.7.1
